==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkExtractPolyDataGeometry.java <==
// java wrapper for vtkExtractPolyDataGeometry object
//

package vtk;
import vtk.*;

public class vtkExtractPolyDataGeometry extends vtkPolyDataAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMTime_2();
  public int GetMTime()
    { return GetMTime_2(); }

  private native void SetImplicitFunction_3(vtkImplicitFunction id0);
  public void SetImplicitFunction(vtkImplicitFunction id0)
    { SetImplicitFunction_3(id0); }

  private native long GetImplicitFunction_4();
  public vtkImplicitFunction GetImplicitFunction() {
    long temp = GetImplicitFunction_4();

    if (temp == 0) return null;
    return (vtkImplicitFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetExtractInside_5(int id0);
  public void SetExtractInside(int id0)
    { SetExtractInside_5(id0); }

  private native int GetExtractInside_6();
  public int GetExtractInside()
    { return GetExtractInside_6(); }

  private native void ExtractInsideOn_7();
  public void ExtractInsideOn()
    { ExtractInsideOn_7(); }

  private native void ExtractInsideOff_8();
  public void ExtractInsideOff()
    { ExtractInsideOff_8(); }

  private native void SetExtractBoundaryCells_9(int id0);
  public void SetExtractBoundaryCells(int id0)
    { SetExtractBoundaryCells_9(id0); }

  private native int GetExtractBoundaryCells_10();
  public int GetExtractBoundaryCells()
    { return GetExtractBoundaryCells_10(); }

  private native void ExtractBoundaryCellsOn_11();
  public void ExtractBoundaryCellsOn()
    { ExtractBoundaryCellsOn_11(); }

  private native void ExtractBoundaryCellsOff_12();
  public void ExtractBoundaryCellsOff()
    { ExtractBoundaryCellsOff_12(); }

  private native void SetPassPoints_13(int id0);
  public void SetPassPoints(int id0)
    { SetPassPoints_13(id0); }

  private native int GetPassPoints_14();
  public int GetPassPoints()
    { return GetPassPoints_14(); }

  private native void PassPointsOn_15();
  public void PassPointsOn()
    { PassPointsOn_15(); }

  private native void PassPointsOff_16();
  public void PassPointsOff()
    { PassPointsOff_16(); }

  public vtkExtractPolyDataGeometry() { super(); }

  public vtkExtractPolyDataGeometry(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-armv7h.pkg.tar.xz: vtk/vtkExtractPolyDataGeometry.java <==
// java wrapper for vtkExtractPolyDataGeometry object
//

package vtk;
import vtk.*;

public class vtkExtractPolyDataGeometry extends vtkPolyDataAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetMTime_2();
  public int GetMTime()
    { return GetMTime_2(); }

  private native void SetImplicitFunction_3(vtkImplicitFunction id0);
  public void SetImplicitFunction(vtkImplicitFunction id0)
    { SetImplicitFunction_3(id0); }

  private native long GetImplicitFunction_4();
  public vtkImplicitFunction GetImplicitFunction() {
    long temp = GetImplicitFunction_4();

    if (temp == 0) return null;
    return (vtkImplicitFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetExtractInside_5(int id0);
  public void SetExtractInside(int id0)
    { SetExtractInside_5(id0); }

  private native int GetExtractInside_6();
  public int GetExtractInside()
    { return GetExtractInside_6(); }

  private native void ExtractInsideOn_7();
  public void ExtractInsideOn()
    { ExtractInsideOn_7(); }

  private native void ExtractInsideOff_8();
  public void ExtractInsideOff()
    { ExtractInsideOff_8(); }

  private native void SetExtractBoundaryCells_9(int id0);
  public void SetExtractBoundaryCells(int id0)
    { SetExtractBoundaryCells_9(id0); }

  private native int GetExtractBoundaryCells_10();
  public int GetExtractBoundaryCells()
    { return GetExtractBoundaryCells_10(); }

  private native void ExtractBoundaryCellsOn_11();
  public void ExtractBoundaryCellsOn()
    { ExtractBoundaryCellsOn_11(); }

  private native void ExtractBoundaryCellsOff_12();
  public void ExtractBoundaryCellsOff()
    { ExtractBoundaryCellsOff_12(); }

  private native void SetPassPoints_13(int id0);
  public void SetPassPoints(int id0)
    { SetPassPoints_13(id0); }

  private native int GetPassPoints_14();
  public int GetPassPoints()
    { return GetPassPoints_14(); }

  private native void PassPointsOn_15();
  public void PassPointsOn()
    { PassPointsOn_15(); }

  private native void PassPointsOff_16();
  public void PassPointsOff()
    { PassPointsOff_16(); }

  public vtkExtractPolyDataGeometry() { super(); }

  public vtkExtractPolyDataGeometry(long id) { super(id); }
  public native long   VTKInit();

}
